function c = molal2molar_sw(press,temp,sal,m)

% MOLAL2MOLAR_SW -  converts solute concentration in molalities [mol/kg]
%      into molarities [mol/l] for standard seawater composition 
%
%      usage: c = molal2molar_sw(p,T,S,m)
%
%       Input parameters (scalars or vectors):
%           p       - pressure [MPa] 
%           T       - temperature [degC] 
%           S       - practical salinity
%           m       - molal concentration of salt component [mol/kg]
%
%       Output parameter: 
%           c       - molar concentration of salt component [mol/l]
%
% ------------------------------------------------------------------
%   written by: Elke Kossel, Matthias Haeckel (August 2009)
%               GEOMAR, Kiel, Germany
%   Disclaimer:
%   This software is provided "as is" without warranty of any kind.
% ------------------------------------------------------------------

% ------------------------------------------------------------------
%   Modification history: 
%       November 2012: syntax changed to Matlab2012 style
% ------------------------------------------------------------------

%------------------------------------------------------------------------
% Check number of input parameters
%------------------------------------------------------------------------

if nargin < 4
     warning('MOLAL2MOLAR_SW:Input','MOLAL2MOLAR_SW: Missing input parameter! Please provide p,T,S and m!')
else

%------------------------------------------------------------------------
% Definition of constants and thermodynamic variables
%------------------------------------------------------------------------
[~,~,S,M] = ndgrid(press,temp,sal,m);    
rho = density_sw(press,temp,sal);

% resize matrix for rho to size of M
rho_2 = zeros(size(M));
for i = 1:size(M,4)
    rho_2(:,:,:,i) = rho;
end

%------------------------------------------------------------------------
% Calculate molarities  
%------------------------------------------------------------------------

c=M.*(1-0.001005.*S).*rho_2./1000;

end