function m = solu_opal(press,temp,sal,choice)

% SOLU_OPAL -  calculates the solubility of opal in seawater
%       The user can choose 2 formalisms for different temperature ranges.
%
%       Usage: m = solu_opal(p,T,S,c)
%
%       Input parameters (scalars or vectors): 
%           p     - pressure [MPa]       (10 < p < 120)
%           T     - temperature [degC]
%           S     - practical salinity   (0 < S < 80) 
%           c     - choice of algorithm
%                    'WALTHER' (default) (0 < T < 350)
%                    'FOURNIER'          (150 < T < 350)
%
%       Output parameters: 
%          m      - solubility of opal [mol/kg]
%
% ------------------------------------------------------------------
%   written by: Elke Kossel, Matthias Haeckel (November 2012)
%               GEOMAR, Kiel, Germany
%   Disclaimer:
%   This software is provided "as is" without warranty of any kind.
% ------------------------------------------------------------------

%------------------------------------------------------------------------
% Check number of input parameters
%------------------------------------------------------------------------

if nargin < 3
     warning('SOLU_OPAL:Input','SOLU_OPAL: Missing input parameter! Please provide p, T and S!')
else
    if nargin == 3
        choice = 'WALTHER';  
    end
    
%------------------------------------------------------------------------
% Algorithm choices
%------------------------------------------------------------------------
switch choice
    case 'WALTHER'
        m = solu_opalWalther(press,temp,sal);
    case 'FOURNIER' 
        m = solu_opalFournier(press,temp,sal);
end

end
